@@ -110,4 +110,4 @@ class Let(AbstractLet):
 
     def __init__(self, f, **kwargs):
         from ldict.core.ldict_ import Ldict
-        super().__init__(f, kwargs, dict_type=Ldict)
+        super().__init__(f, kwargs, dict_type=Ldict, fs_type=FunctionSpace)
